Overview
--------

**tickcounter** is a Python package built to facilitate the process of cleaning, manipulating and analyzing questionnaire or survey related data effectively. 

Installation
------
You can install the latest version using `pip`.

```
pip install tickcounter
```

Dependencies
----
- python: >=3.7.1
- pandas: >=1.3.5
- scipy: >=1.4.1
- matplotlib: >=3.2.2
- seaborn: >=0.11.2

Usage
----
Documentation is still under development. Meanwhile, you can look at some notebook examples in the `examples` folder.

A Word of Caution
----
The interfaces are still unstable and are most likely to change in the near future.
